//**************************************************************
// ****** FUNCTIONS FOR SD RAW DATA TRANSFER *******
//**************************************************************
//Controller: ATmega32 (Clock: 8 Mhz-internal)
//Compiler	: AVR-GCC (winAVR with AVRStudio)
//Version 	: 2.3
//Author	: CC Dharmani, Chennai (India)
//			  www.dharmanitech.com
//Date		: 08 May 2010
//**************************************************************

//**************************************************
// ***** HEADER FILE : SD_routines.h ******
//**************************************************

/**
	gravement modifié par Silicium628
	2015-07-23
**/

#ifndef _SDcard_628_2_H_
#define _SDcard_628_2_H_

//Use following macro if you don't want to activate the multiple block access functions
//those functions are not required for FAT32

#define FAT_TESTING_ONLY         

//use following macros if SS (PB4) pin is used for Chip Select of SD
#define pin_CS 0b00010000
#define SD_CS_ASSERT     PORTB &= ~pin_CS
#define SD_CS_DEASSERT   PORTB |= pin_CS

//SD commands, many of these are not used here
#define GO_IDLE_STATE             0
#define SEND_OP_COND              1
#define SEND_IF_COND							8
#define SEND_CSD									9
#define STOP_TRANSMISSION        12
#define SEND_STATUS              13
#define SET_BLOCK_LEN            16
#define READ_SINGLE_BLOCK        17
#define READ_MULTIPLE_BLOCKS     18
#define WRITE_SINGLE_BLOCK       24
#define WRITE_MULTIPLE_BLOCKS    25
#define ERASE_BLOCK_START_ADDR   32
#define ERASE_BLOCK_END_ADDR     33
#define ERASE_SELECTED_BLOCKS    38
#define SD_SEND_OP_COND			 		 41   //ACMD
#define APP_CMD					 				 55
#define READ_OCR				         58
#define CRC_ON_OFF               59


#define ON     1
#define OFF    0

volatile uint8_t buffer[512];  

volatile uint32_t startBlock, totalBlocks; 
volatile uint8_t SDHC_flag, cardType;

uint8_t SD_init(void);
uint8_t SD_sendCommand(uint8_t cmd, uint32_t arg);
uint8_t SD_readSingleBlock(uint32_t startBlock);
uint8_t SD_writeSingleBlock(uint32_t startBlock);
uint8_t SD_readMultipleBlock (uint32_t startBlock, uint32_t totalBlocks);
uint8_t SD_writeMultipleBlock(uint32_t startBlock, uint32_t totalBlocks);
uint8_t SD_erase (uint32_t startBlock, uint32_t totalBlocks);

#endif
